timeseries.SpaceCurve
=====================

.. currentmodule:: timeseries

.. autoclass:: SpaceCurve

   

      .. autosummary::
         :toctree:
      
         SpaceCurve.accel
         SpaceCurve.arclength_param
         SpaceCurve.auto_bin
         SpaceCurve.clean_copy
         SpaceCurve.compute
         SpaceCurve.copy
         SpaceCurve.duration
         SpaceCurve.featurize
         SpaceCurve.lift_and_mass
         SpaceCurve.lift_profile
         SpaceCurve.load
         SpaceCurve.mass_profile
         SpaceCurve.plot
         SpaceCurve.reparam
         SpaceCurve.reverse
         SpaceCurve.signature_curve
         SpaceCurve.slide
         SpaceCurve.snip



   

